@@ -111,8 +111,7 @@ setMethodS3("writeAsFullCelFile", "ChipEffectFile", function(this, name=getName(
   } 
 
   if (!is.null(tags)) {
-    tags <- paste(tags, collapse=",");
-    tags <- unlist(strsplit(tags, split=",", fixed=TRUE));
+    tags <- Arguments$getTags(tags, collapse=NULL);
     idx <- which(tags == "*");
     if (length(idx) > 0)
       tags <- insert(tags[-idx], at=idx, getTags(this));
@@ -185,8 +184,7 @@ setMethodS3("getAsFullCelFile", "ChipEffectFile", function(this, name=getName(th
   } 
 
   if (!is.null(tags)) {
-    tags <- paste(tags, collapse=",");
-    tags <- unlist(strsplit(tags, split=",", fixed=TRUE));
+    tags <- Arguments$getTags(tags, collapse=NULL);
     idx <- which(tags == "*");
     if (length(idx) > 0) {
       tags <- insert(tags[-idx], at=idx, getTags(this));
