@@ -29,7 +29,7 @@
 # }
 #*/###########################################################################
 setConstructorS3("CnChipEffectFile", function(..., combineAlleles=FALSE) {
-  this <- extend(SnpChipEffectFile(...), "CnChipEffectFile",
+  this <- extend(SnpChipEffectFile(...), c("CnChipEffectFile", uses("CopyNumberDataFile")),
     combineAlleles = combineAlleles
   );
 
@@ -40,6 +40,17 @@ setConstructorS3("CnChipEffectFile", function(..., combineAlleles=FALSE) {
   this;
 })
 
+setMethodS3("hasAlleleBFractions", "CnChipEffectFile", function(this, ...) {
+  res <- (!this$combineAlleles);
+  res;
+})
+
+setMethodS3("hasStrandiness", "CnChipEffectFile", function(this, ...) {
+  res <- (!this$mergeStrands);
+  res;
+})
+
+
 setMethodS3("getParameters", "CnChipEffectFile", function(this, ...) {
   params <- NextMethod(generic="getParameters", object=this, ...);
   params$combineAlleles <- this$combineAlleles;
@@ -55,7 +66,7 @@ setMethodS3("getCellIndices", "CnChipEffectFile", function(this, units=NULL, ...
   # Argument 'units':
   if (is.null(units)) {
   } else if (is.numeric(units)) {
-    units <- Arguments$getIndices(units, range=c(1, nbrOfUnits(cdf)));
+    units <- Arguments$getIndices(units, max=nbrOfUnits(cdf));
   }
 
   # Argument 'verbose':
@@ -229,8 +240,63 @@ setMethodS3("mergeStrands", "CnChipEffectFile", function(this, ...) {
   cfM;
 })
 
+
+setMethodS3("getNumberOfFilesAveraged", "CnChipEffectFile", function(this, ..., verbose=FALSE) {
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Validate arguments
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Argument 'verbose':
+  verbose <- Arguments$getVerbose(verbose);
+  if (verbose) {
+    pushState(verbose);
+    on.exit(popState(verbose));
+  }
+
+  verbose && enter(verbose, "Querying ", class(this)[1], " for the number of arrays used to calculate average");
+  pathname <- getPathname(this);
+  verbose && cat(verbose, "Pathname: ", pathname);
+
+  # Make sure it is a file calculated by getAverageFile()
+  if (!isAverageFile(this)) {
+    throw("Cannot retrieve the number of arrays used when averaging. The file is not generated by getAverageFile(), because the filename does not start with '.average-': ", pathname);
+  }
+
+  # Get (unit, group, cell) map
+  ugcMap <- getUnitGroupCellMap(this, ..., verbose=less(verbose, 5));
+
+  # Keep only first group (in case mergeStrands or combineAlleles is FALSE)
+  # To please R CMD check
+  group <- NULL; rm(group);
+  ugcMap <- subset(ugcMap, group == 1);
+
+  cells <- ugcMap[,"cell", drop=TRUE];
+  rm(ugcMap);
+
+  verbose && cat(verbose, "Cell indices:");
+  verbose && str(verbose, cells);
+
+  verbose && enter(verbose, "Reading data");
+  data <- readCel(pathname, indices=cells, readIntensities=FALSE, 
+                  readPixels=TRUE);
+  verbose && exit(verbose);
+
+  ns <- data$pixels;
+  rm(data);
+
+  verbose && exit(verbose);
+
+  ns;
+}, protected=TRUE); # getNumberOfFilesAveraged()
+
+
 ############################################################################
 # HISTORY:
+# 2009-11-18
+# o Added getNumberOfFilesAveraged() for CnChipEffectFile.  It should only
+#   be used for files generated by getAverageFile(), otherwise an error
+#   is thrown.
+# 2009-11-17
+# o Now CnChipEffectFile implements CopyNumberDataFile.
 # 2008-02-19
 # o BUG FIX: getCellIndices() of CnChipEffectFile would return an error
 #   if 'units==NULL'.
